@@ -37,12 +37,14 @@ class ExtensionModule():
 class Taxonomy():
 
     def __init__(self, id, title, column_types, header_mapping,
-                 processing_module, publishing_module, config):
+                 processing_module, publishing_module, loading_module,
+                 config):
         self.id = id
         self.title = title
         self.header_mapping = header_mapping
         self.processing = ExtensionModule(processing_module)
         self.publishing = ExtensionModule(publishing_module)
+        self.loading = ExtensionModule(loading_module)
         self.config = config
         self.missingValues = self.config.get('missingValues', []) if self.config else []
         if '' not in self.missingValues:
@@ -86,6 +88,7 @@ class TaxonomyRegistry():
                     ('header_mapping', yaml.load),
                     ('processing_module', load_module),
                     ('publishing_module', load_module),
+                    ('loading_module', load_module),
                     ('config', None),
                     ]:
                 value = v.get(key)
